@@ -16,7 +16,7 @@ class BrandingMiddleware(object):
         """Add custom headers
         """
 
-        for key, value in settings.BRANDING:
+        for key, value in getattr(settings, 'BRANDING', {}).iteritems():
             response[key] = value
 
         platform = getattr(settings, "PLATFORM")
